@@ -1,12 +1,16 @@
 package org.gcube.portlets.user.td.openwidget.client;
 
-import org.gcube.portlets.user.td.openwidget.client.general.WizardWindow;
-import org.gcube.portlets.user.td.gwtservice.shared.TDOpenSession;
+import org.gcube.portlets.user.td.wizardwidget.client.WizardWindow;
+import org.gcube.portlets.user.td.gwtservice.shared.tr.open.TDOpenSession;
 
 import com.allen_sauer.gwt.log.client.Log;
+import com.google.web.bindery.event.shared.EventBus;
 
 /**
- * Entry point classes define <code>onModuleLoad()</code>.
+ * 
+ * @author "Giancarlo Panichi" 
+ * <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
+ *
  */
 public class TDOpen  extends WizardWindow   {
 
@@ -17,18 +21,21 @@ public class TDOpen  extends WizardWindow   {
 	 * @param targetId
 	 */
 	
-	public TDOpen(String title)	{
-		super(title);
+	public TDOpen(String title,EventBus eventBus)	{
+		super(title,eventBus);
 		Log.info("TDOpen: "+title);
 		setWidth(550);
 		setHeight(520);
+		BUTTONNEXTLABEL="Open";
+		nextButton.setText(BUTTONNEXTLABEL);
 		
+		setEnableNextButton(false);
 		tdOpenSession= new TDOpenSession();
 		
 		
 		TabResourcesSelectionCard tabResourcesSelection= new TabResourcesSelectionCard(tdOpenSession);
 		addCard(tabResourcesSelection);
-		
+		tabResourcesSelection.setup();
 		
 	}
 		
